@@ -24,6 +24,14 @@ SYSTEM_TASK_SERVICE_ACCOUNT_EMAIL                   = os.environ.get('SYSTEM_TAS
 
 SYSTEM_BASE_URL                                     = os.environ.get('SYSTEM_BASE_URL')
 
+
+STORAGE_SERVICE_ACCOUNT_KEY_FILEPATH                = os.environ['CLOUD_STORAGE_SERVICE_ACCOUNT_KEY']
+STORAGE_CREDENTIAL_PATH                             = os.path.abspath(os.path.dirname(__file__)) + '/../' + STORAGE_SERVICE_ACCOUNT_KEY_FILEPATH
+
+CLOUD_STORAGE_BUCKET                                = os.environ.get('CLOUD_STORAGE_BUCKET')
+CLOUD_STORAGE_PROJECT_ID                            = os.environ.get('CLOUD_STORAGE_PROJECT_ID')
+
+
 def task_url(path):
     return '{}{}'.format(SYSTEM_BASE_URL, path)
 
